==> jc-1.4.0.tar.gz: gnu/xml/transform/TemplateNode.h <==
// abstract class gnu.xml.transform.TemplateNode

// class file dependencies
// @dep_class ef8509869908c7a6 gnu_xml_transform_TemplateNode
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_transform_TemplateNode_H_
#define _JC_gnu_xml_transform_TemplateNode_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_transform_TemplateNode$object;
struct _jc_java_io_PrintStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Comparator$object;
struct _jc_javax_xml_namespace_QName$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_TemplateNode$sub_refs	_jc_gnu_xml_transform_TemplateNode$sub_refs;
typedef struct _jc_gnu_xml_transform_TemplateNode$sub_nonrefs	_jc_gnu_xml_transform_TemplateNode$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_TemplateNode$refs	_jc_gnu_xml_transform_TemplateNode$refs;
typedef struct _jc_gnu_xml_transform_TemplateNode$nonrefs	_jc_gnu_xml_transform_TemplateNode$nonrefs;
typedef struct _jc_gnu_xml_transform_TemplateNode$object	_jc_gnu_xml_transform_TemplateNode$object;

typedef struct _jc_gnu_xml_transform_TemplateNode$fields_struct	_jc_gnu_xml_transform_TemplateNode$fields_struct;
typedef const struct _jc_gnu_xml_transform_TemplateNode$vmethods	_jc_gnu_xml_transform_TemplateNode$vmethods;
typedef const struct _jc_gnu_xml_transform_TemplateNode$vtable	_jc_gnu_xml_transform_TemplateNode$vtable;
typedef const struct _jc_gnu_xml_transform_TemplateNode$vtype	_jc_gnu_xml_transform_TemplateNode$vtype;

// Class fields structure
struct _jc_gnu_xml_transform_TemplateNode$fields_struct {
	struct _jc_object	*documentOrderComparator;
};
extern _jc_gnu_xml_transform_TemplateNode$fields_struct _jc_gnu_xml_transform_TemplateNode$class_fields;

// Constructors
extern void _jc_gnu_xml_transform_TemplateNode$method$_init$397d752fa8327fc4(_jc_env *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *);

// Virtual methods
extern void _jc_gnu_xml_transform_TemplateNode$method$apply$8027ba827620777d(_jc_env *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *);
extern struct _jc_gnu_xml_transform_TemplateNode$object *_jc_gnu_xml_transform_TemplateNode$method$clone$b8a038f4254cb648(_jc_env *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);
extern void _jc_gnu_xml_transform_TemplateNode$method$doApply$85a30cd55d4e7167(_jc_env *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *);
extern void _jc_gnu_xml_transform_TemplateNode$method$list$8888f41c84ad0669(_jc_env *, struct _jc_gnu_xml_transform_TemplateNode$object *, jint, struct _jc_java_io_PrintStream$object *, jboolean);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_TemplateNode$method_info$apply$8027ba827620777d;
extern _jc_method _jc_gnu_xml_transform_TemplateNode$method_info$clone$b8a038f4254cb648;
extern _jc_method _jc_gnu_xml_transform_TemplateNode$method_info$doApply$85a30cd55d4e7167;
extern _jc_method _jc_gnu_xml_transform_TemplateNode$method_info$list$8888f41c84ad0669;

// Static methods
extern void _jc_gnu_xml_transform_TemplateNode$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_xml_transform_TemplateNode$vmethods {
	void	(*apply$8027ba827620777d)(_jc_env *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *);
	struct _jc_gnu_xml_transform_TemplateNode$object	*(*clone$b8a038f4254cb648)(_jc_env *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);
	void	(*doApply$85a30cd55d4e7167)(_jc_env *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *);
	void	(*list$8888f41c84ad0669)(_jc_env *, struct _jc_gnu_xml_transform_TemplateNode$object *, jint, struct _jc_java_io_PrintStream$object *, jboolean);
};

// Vtable
struct _jc_gnu_xml_transform_TemplateNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_TemplateNode$vmethods	gnu_xml_transform_TemplateNode;
};

// Vtype
struct _jc_gnu_xml_transform_TemplateNode$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_TemplateNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_TemplateNode$sub_refs {
	struct _jc_gnu_xml_transform_TemplateNode$object	*children;
	struct _jc_gnu_xml_transform_TemplateNode$object	*next;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_TemplateNode$refs {
    _jc_gnu_xml_transform_TemplateNode$sub_refs	gnu_xml_transform_TemplateNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_TemplateNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_TemplateNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_TemplateNode$sub_nonrefs	gnu_xml_transform_TemplateNode;
};

// Object instance structure
struct _jc_gnu_xml_transform_TemplateNode$object {
	_jc_gnu_xml_transform_TemplateNode$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_TemplateNode$vtype	*vtype;
	_jc_gnu_xml_transform_TemplateNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_TemplateNode$vtype _jc_gnu_xml_transform_TemplateNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_TemplateNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_TemplateNode$class_object;

#endif	/* _JC_gnu_xml_transform_TemplateNode_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/transform/TemplateNode.h <==
// abstract class gnu.xml.transform.TemplateNode

// class file dependencies
// @dep_class ef8509869908c7a6 gnu_xml_transform_TemplateNode
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_transform_TemplateNode_H_
#define _JC_gnu_xml_transform_TemplateNode_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_transform_TemplateNode$object;
struct _jc_java_io_PrintStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Comparator$object;
struct _jc_javax_xml_namespace_QName$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_TemplateNode$sub_refs	_jc_gnu_xml_transform_TemplateNode$sub_refs;
typedef struct _jc_gnu_xml_transform_TemplateNode$sub_nonrefs	_jc_gnu_xml_transform_TemplateNode$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_TemplateNode$refs	_jc_gnu_xml_transform_TemplateNode$refs;
typedef struct _jc_gnu_xml_transform_TemplateNode$nonrefs	_jc_gnu_xml_transform_TemplateNode$nonrefs;
typedef struct _jc_gnu_xml_transform_TemplateNode$object	_jc_gnu_xml_transform_TemplateNode$object;

typedef struct _jc_gnu_xml_transform_TemplateNode$fields_struct	_jc_gnu_xml_transform_TemplateNode$fields_struct;
typedef const struct _jc_gnu_xml_transform_TemplateNode$vmethods	_jc_gnu_xml_transform_TemplateNode$vmethods;
typedef const struct _jc_gnu_xml_transform_TemplateNode$vtable	_jc_gnu_xml_transform_TemplateNode$vtable;
typedef const struct _jc_gnu_xml_transform_TemplateNode$vtype	_jc_gnu_xml_transform_TemplateNode$vtype;

// Class fields structure
struct _jc_gnu_xml_transform_TemplateNode$fields_struct {
	struct _jc_object	*documentOrderComparator;
};
extern _jc_gnu_xml_transform_TemplateNode$fields_struct _jc_gnu_xml_transform_TemplateNode$class_fields;

// Constructors
extern void _jc_gnu_xml_transform_TemplateNode$method$_init$397d752fa8327fc4(_jc_env *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_xml_transform_TemplateNode$method$apply$8027ba827620777d(_jc_env *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_xml_transform_TemplateNode$object *_jc_gnu_xml_transform_TemplateNode$method$clone$b8a038f4254cb648(_jc_env *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_transform_TemplateNode$method$doApply$85a30cd55d4e7167(_jc_env *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_transform_TemplateNode$method$list$8888f41c84ad0669(_jc_env *, struct _jc_gnu_xml_transform_TemplateNode$object *, jint, struct _jc_java_io_PrintStream$object *, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_TemplateNode$method_info$apply$8027ba827620777d;
extern _jc_method _jc_gnu_xml_transform_TemplateNode$method_info$clone$b8a038f4254cb648;
extern _jc_method _jc_gnu_xml_transform_TemplateNode$method_info$doApply$85a30cd55d4e7167;
extern _jc_method _jc_gnu_xml_transform_TemplateNode$method_info$list$8888f41c84ad0669;

// Static methods
extern void _jc_gnu_xml_transform_TemplateNode$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_transform_TemplateNode$vmethods {
	void	(*apply$8027ba827620777d)(_jc_env *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_gnu_xml_transform_TemplateNode$object	*(*clone$b8a038f4254cb648)(_jc_env *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;
	void	(*doApply$85a30cd55d4e7167)(_jc_env *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*list$8888f41c84ad0669)(_jc_env *, struct _jc_gnu_xml_transform_TemplateNode$object *, jint, struct _jc_java_io_PrintStream$object *, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_transform_TemplateNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_TemplateNode$vmethods	gnu_xml_transform_TemplateNode;
};

// Vtype
struct _jc_gnu_xml_transform_TemplateNode$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_TemplateNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_TemplateNode$sub_refs {
	struct _jc_gnu_xml_transform_TemplateNode$object	*children;
	struct _jc_gnu_xml_transform_TemplateNode$object	*next;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_TemplateNode$refs {
    _jc_gnu_xml_transform_TemplateNode$sub_refs	gnu_xml_transform_TemplateNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_TemplateNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_TemplateNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_TemplateNode$sub_nonrefs	gnu_xml_transform_TemplateNode;
};

// Object instance structure
struct _jc_gnu_xml_transform_TemplateNode$object {
	_jc_gnu_xml_transform_TemplateNode$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_TemplateNode$vtype	*vtype;
	_jc_gnu_xml_transform_TemplateNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_TemplateNode$vtype _jc_gnu_xml_transform_TemplateNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_TemplateNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_TemplateNode$class_object;

#endif	/* _JC_gnu_xml_transform_TemplateNode_H_ */
